"use strict";

exports.__esModule = true;
exports.schedule = schedule;
exports.flush = flush;
exports.scheduleEffect = scheduleEffect;
exports.flushEffect = flushEffect;
var scheduler;

if (process.env.NODE_ENV !== 'production') {
  // For jest hijack timers
  scheduler = function scheduler(callback) {
    setTimeout(callback);
  };
} else {
  scheduler = typeof Promise == 'function' ? Promise.prototype.then.bind(Promise.resolve()) : setTimeout;
}

var updateCallbacks = [];
var effectCallbacks = []; // Schedule before next render

function schedule(callback) {
  if (updateCallbacks.length === 0) {
    scheduler(flush);
  }

  updateCallbacks.push(callback);
} // Flush before next render


function flush() {
  var callbacks = updateCallbacks;

  if (callbacks.length !== 0) {
    updateCallbacks = [];
    callbacks.forEach(function (callback) {
      return callback();
    });
  }
}

function scheduleEffect(callback) {
  if (effectCallbacks.length === 0) {
    scheduler(flushEffect);
  }

  effectCallbacks.push(callback);
}

function flushEffect() {
  var callbacks = effectCallbacks;

  if (callbacks.length !== 0) {
    effectCallbacks = [];
    callbacks.forEach(function (callback) {
      return callback();
    });
  }
}